==> netcdf-4.3.9-20120425.180533-3-sources.jar: ucar/nc2/util/net/HTTPAuthScheme.java <==
/*
 * Copyright 1998-2009 University Corporation for Atmospheric Research/Unidata
 *
 * Portions of this software were developed by the Unidata Program at the
 * University Corporation for Atmospheric Research.
 *
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation.  Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 *
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package ucar.nc2.util.net;

/**
 * HTTPAuthScheme defines an enum about the currently supported schemes.
 */

public enum HTTPAuthScheme
{
    BASIC("BASIC"),
    DIGEST("DIGEST"),
    SSL("SSL"),
    PROXY("PROXY"),
    ANY("ANY");

    // Define the associated standard name
    private final String name;

    HTTPAuthScheme(String name)
    {
        this.name = name;
    }

    public String getSchemeName()   { return name; }
 
    static public HTTPAuthScheme schemeForName(String name)
    {
	if(name != null) {
  	    for(HTTPAuthScheme s: HTTPAuthScheme.values()) {
  	        if(name.equalsIgnoreCase(s.name())) return s;
	    }
	}
	return null;
    }

    static public HTTPAuthScheme fromAuthScope(String scheme)
    {
	if(scheme == null) return null;
	if(scheme.equals(org.apache.commons.httpclient.auth.AuthPolicy.BASIC)) return BASIC;
	if(scheme.equals(org.apache.commons.httpclient.auth.AuthPolicy.DIGEST)) return DIGEST;
	return null;
    }
}

==> netcdf-4.3.21-sources.jar: ucar/nc2/util/net/HTTPAuthScheme.java <==
/*
 * Copyright 1998-2009 University Corporation for Atmospheric Research/Unidata
 *
 * Portions of this software were developed by the Unidata Program at the
 * University Corporation for Atmospheric Research.
 *
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation.  Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 *
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package ucar.nc2.util.net;

/**
 * HTTPAuthScheme defines an enum about the currently supported schemes.
 */

public enum HTTPAuthScheme
{
    BASIC("BASIC"),
    DIGEST("DIGEST"),
    SSL("SSL"),
    NTLM("NTLM"),
    ANY("ANY");

    // Define the associated standard name
    private final String name;

    HTTPAuthScheme(String name)
    {
        this.name = name;
    }

    public String getSchemeName()   { return name; }
 
    static public HTTPAuthScheme schemeForName(String name)
    {
	if(name != null) {
  	    for(HTTPAuthScheme s: HTTPAuthScheme.values()) {
  	        if(name.equalsIgnoreCase(s.name())) return s;
	    }
	}
	return null;
    }

    static public HTTPAuthScheme fromAuthScope(String scheme)
    {
	if(scheme == null) return null;
	if(scheme.equals(org.apache.commons.httpclient.auth.AuthPolicy.BASIC))
	    return BASIC;
	if(scheme.equals(org.apache.commons.httpclient.auth.AuthPolicy.DIGEST))
	    return DIGEST;
	if(scheme.equals(org.apache.commons.httpclient.auth.AuthPolicy.NTLM))
	    return NTLM;
	return null;
    }
}
